@@ -30,6 +30,7 @@ enum CategoryId {
     TimeCategory,
     FuelEfficiencyCategory,
     DensityCategory,
+    WeightPerAreaCategory,
     AccelerationCategory,
     AngleCategory,
     FrequencyCategory,
@@ -116,6 +117,12 @@ enum UnitId {
     AstronomicalUnit,
     Thou,
     Angstrom,
+    RackUnit,
+    Link,
+    Chain,
+    Furlong,
+    Fathom,
+    RodPerchPole,
 
     // Volume
     CubicYottameter = 3000,
@@ -337,6 +344,7 @@ enum UnitId {
     Zar,
     Ils,
     Isk,
+    Xpf, /// @since 6.9
 
     // Velocity
     MeterPerSecond = 9000,
@@ -446,6 +454,10 @@ enum UnitId {
     PoundPerCubicFoot,
     PoundPerCubicYard,
 
+    // Weight per area
+    GramsPerSquareMeter,
+    OuncesPerSquareYard,
+
     // Acceleration
     MetresPerSecondSquared = 14000,
     FeetPerSecondSquared,
@@ -767,35 +779,18 @@ public:
      **/
     Unit(const Unit &other);
 
-    // TODO KF6: remove virtual
-    virtual ~Unit();
+    ~Unit();
 
     /**
      * Assignment operator, assign @p other to this.
      **/
     Unit &operator=(const Unit &other);
 
-    // TODO KF6: de-inline
-#ifdef Q_COMPILER_RVALUE_REFS
     /**
      * Move-assigns @p other to this Unit instance, transferring the
      * ownership of the managed pointer to this instance.
      **/
-    Unit &operator=(Unit &&other)
-    {
-        swap(other);
-        return *this;
-    }
-#endif
-
-    // TODO KF6: remove
-    /**
-     * Swaps this Unit with @p other. This function is very fast and never fails.
-     **/
-    void swap(Unit &other)
-    {
-        d.swap(other.d);
-    }
+    Unit &operator=(Unit &&other);
 
     /**
      * @return @c true if this Unit is equal to the @p other Unit.
@@ -876,12 +871,15 @@ private:
     friend class UnitCategoryPrivate;
     friend class CurrencyCategoryPrivate;
 
-    Unit(UnitPrivate *dd);
-    void setUnitMultiplier(qreal multiplier);
+    KUNITCONVERSION_NO_EXPORT explicit Unit(UnitPrivate *dd);
+
+    KUNITCONVERSION_NO_EXPORT void setUnitMultiplier(qreal multiplier);
 
     QExplicitlySharedDataPointer<UnitPrivate> d;
 };
 
 } // KUnitConversion namespace
 
+Q_DECLARE_TYPEINFO(KUnitConversion::Unit, Q_RELOCATABLE_TYPE);
+
 #endif
